/****************************************************************************
 Include Section
*****************************************************************************/

/*****************************************************************************
 Symbolic constants / definitions
******************************************************************************/

#define RDAC_STEP_VALUE_110 0x37 /* Digipot step value 0x37 gives us 1.10V */
#define RDAC_STEP_VALUE_115 0x2D /* Digipot step value 0x2D gives us 1.15V */
#define RDAC_STEP_VALUE_120 0x23 /* Digipot step value 0x23 gives us 1.20V */
#define RDAC_STEP_VALUE_125 0x1A /* Digipot step value 0x1A gives us 1.25V */
#define RDAC_STEP_VALUE_130 0x12 /* Digipot step value 0x12 gives us 1.30V */
#define RDAC_STEP_VALUE_135 0x0A /* Digipot step value 0x0A gives us 1.35V */
#define RDAC_STEP_VALUE_140 0x03 /* Digipot step value 0x03 gives us 1.40V */


/* ************************************ UART CONTROLLER MASKS *****************************************************/

/* PLL_STAT Masks */
#define VSTAT           0x0080  /* Voltage Regulator Status: Regulator at programmed voltage */

/* Bit masks for UART Divisor Latch Registers: UARTx_DLL & UARTx_DLH */
#define UARTDLL         0x00FF  /* Divisor Latch Low Byte */
#define UARTDLH         0xFF00  /* Divisor Latch High Byte */


/*****************************************************************************
 Dynamic Power Managment
*****************************************************************************/

/*************************************************
* To activate PLL and Voltage Regulator settings *
* uncomment the following definition             *
*************************************************/

#define __ACTIVATE_DPM__


/********************************
* PLL Control Register Value    *
* Reset = 0x0A00                *
* ADSP-BF506F EZ-Board:         *
* CLKIN = 25MHz                 *
* MSEL = 12                     *
* --> VCO = 25MHz x 12 = 300MHz *
********************************/

#define PLL_CTL_VAL             (\
                               nBYPASS              |   /* Bypass the PLL */\
                               nOUT_DELAY           |   /* Add 200ps Delay To EBIU Output Signals */\
                               nIN_DELAY            |   /* Add 200ps Delay To EBIU Input Latches */\
                               nPDWN                |   /* Enter Deep Sleep Mode */\
                               nSTOPCK              |   /* Core Clock Off */\
                               nPLL_OFF             |   /* PLL Not Powered */\
                               nDF                  |   /* 0: PLL = CLKIN, 1: PLL = CLKIN/2 */\
                                SET_MSEL(16)        |   /* Set MSEL = 0-63 --> VCO = CLKIN*MSEL */\
                                0)

#define CLKIN_Hz                 25000000           /* CLKIN [Hz] */
#define VCO_MAX_Hz              400000000           /* VCO [Hz] */
#define VCO_MIN_Hz               50000000           /* VCO [Hz] */


/*********************************
* PLL Divide Register Value      *
* Reset = 0x0004                 *
* ADSP-BF506F EZ-Board:          *
* CSEL = 1                       *
* --> CCLK = VCO / CSEL          *
* --> CCLK = 300MHz / 1 = 300MHz *
* SSEL = 4                       *
* --> SCLK = VCO / SSEL          *
* --> SCLK = 300MHz / 4 = 75MHz  *
*********************************/

#define PLL_DIV_VAL             (\
                                SET_SSEL(5)         |   /* Set SSEL = 1-15 --> SCLK = VCO/SSEL */\
                                CSEL_DIV1           |   /* CCLK = VCO / 1 */\
                                0)

#define CCLK_MAX_Hz             VCO_MAX_Hz          /* Maximum Core Clock [Hz] */
#define SCLK_MAX_Hz             80000000            /* Maximum System Clock [Hz] */


/********************************
* PLL Lock Count Register Value *
* Reset = 0x0200                *
********************************/

#define PLL_LOCKCNT_VAL         0x0200


/****************************
* PLL Status Register Value *
* Reset = 0x00A2            *
****************************/

#define PLL_STAT_VAL            (\
                                VSTAT               |   /* Voltage Regulator Status: Regulator at programmed voltage */\
                                PLL_LOCKED          |   /* PLL Locked Status */\
                               nACTIVE_PLLDISABLED  |   /* Active Mode With PLL Disabled */\
                                FULL_ON             |   /* Full-On Mode */\
                               nACTIVE_PLLENABLED   |   /* Active Mode With PLL Enabled */\
                                0)


/*******************************************
* Voltage Regulator Control Register Value *
* Reset = 0x70B0                           *
*******************************************/

#define VR_CTL_VAL              (\
                               nSCKELOW         |   /* Enable Drive CKE Low During Reset */\
                               nWAKE            |   /* Enable RTC/Reset Wakeup From Hibernate */\
                               nPHYWE           |   /* Enable PHY Wakeup From Hibernate */\
                                CLKBUFOE        |   /* CLKIN Buffer Output Enable */\
                                0x00B0          |   /* Bits #7,6 set by default */\
                                FREQ            |   /* FREQ=00 indicates hibernate. FREQ=11 indicates non-Hibernate */\
                                0)


/*****************************
* External Voltage Regulator *
* Digipot Value              *
*****************************/

#define RDAC_STEP_VAL           RDAC_STEP_VALUE_140     /* Digipot step value for 1.40V */


/*****************************************************************************
 EBIU: Asynchronous Memory
*****************************************************************************/


/****************************************************
* Asynchronous Memory Global Control Register Value *
* Reset = 0x00F2                                    *
* --> Enabling all four Async Banks and Clock Out   *
****************************************************/

#define EBIU_AMGCTL_VAL         (\
                               nCDPRIO          |   /* Core/DMA Priority */\
                               nAMCKEN          |   /* Enable CLKOUT */\
                                AMBEN_ALL       |   /* Enable Asynchronous memory bank */\
                                0)


/******************************************************
* Asynchronous Memory Bank Control (0) Register Value *
* Reset = 0x0000 FFC2                                 *
******************************************************/

#define EBIU_AMBCTL0_VAL        (\
                                B0WAT_5         |   /* B0 Write Access Time = 5 cycles */\
                                B0RAT_6         |   /* B0 Read Access Time = 6 cycles */\
                                B0HT_1          |   /* B0 Hold Time (nRead/Write to nAOE) = 1 cycles */\
                                B0ST_2          |   /* B0 Setup Time from AOE asserted to Read/Write asserted = 2 cycles */\
                                B0TT_1          |   /* B0 Transition Time (Read to Write) = 1 cycles */\
                                0)


/**************************************************
* Asynchronous Memory Mode Control Register Value *
* Reset = 0x0001                                  *
**************************************************/

#define EBIU_MODE_VAL           (\
                                MODE_FLASH      |   /* Asynchronous Flash Mode */\
                                0)


/*******************************************************
* Asynchronous Memory Parameter Control Register Value *
* Reset = 0x0002                                       *
*******************************************************/

#define EBIU_FCTL_VAL           (\
                                BCLK2           |   /* Burst clock frequency: 01 - SCLK/2 */\
                                0)


/**********************************************************
* BMODE_SPIMEM: Boot from SPI memory                      *
* This definition will modify the SPI_BAUD register value *
* and can in/decrease boot speed                          *
* Boot Rom default: 0x85                                  *
**********************************************************/

#define SPI_BAUD_VAL            0x85


/****************************************************************************
 EOF
*****************************************************************************/
